
"""
Ask More Questions.
Author: Ron Nathaniel
"""

from how.crawler import ask_sof, ask_google

__author__ = "Ron Nathaniel"
__copyright__ = "Copyright 2022"
__credits__ = ["Ron Nathaniel", "Itay Bachar", "Ty Vered", "Itamar Golomb"]
__license__ = "MIT"
__maintainer__ = "Ron Nathaniel"
__email__ = "rnathaniel7@gmail.com"
__status__ = "Production"